@@ -4,13 +4,14 @@ from operator import getitem
 
 import numpy as np
 
-from .core import getarray, getarray_nofancy
-from ..core import flatten
+from .core import getarray, getarray_nofancy, getarray_inline
+from ..core import flatten, reverse_dict
 from ..optimize import cull, fuse, inline_functions
+from ..utils import ensure_dict
 
 
 def optimize(dsk, keys, fuse_keys=None, fast_functions=None,
-             inline_functions_fast_functions=None, rename_fused_keys=True,
+             inline_functions_fast_functions=(getarray_inline,), rename_fused_keys=True,
              **kwargs):
     """ Optimize dask for array computation
 
@@ -18,22 +19,58 @@ def optimize(dsk, keys, fuse_keys=None, fast_functions=None,
     2.  Remove full slicing, e.g. x[:]
     3.  Inline fast functions like getitem and np.transpose
     """
+    dsk = ensure_dict(dsk)
     keys = list(flatten(keys))
     if fast_functions is not None:
         inline_functions_fast_functions = fast_functions
 
-    if inline_functions_fast_functions is None:
-        inline_functions_fast_functions = {getarray, getarray_nofancy,
-                                           np.transpose}
-
     dsk2, dependencies = cull(dsk, keys)
-    dsk4, dependencies = fuse(dsk2, keys + (fuse_keys or []), dependencies,
-                              rename_fused_keys=rename_fused_keys)
-    dsk5 = optimize_slices(dsk4)
-    dsk6 = inline_functions(dsk5, keys, dependencies=dependencies,
-                            fast_functions=inline_functions_fast_functions)
+    hold = hold_keys(dsk2, dependencies)
 
-    return dsk6
+    dsk3, dependencies = fuse(dsk2, hold + keys + (fuse_keys or []),
+                              dependencies, rename_keys=rename_fused_keys)
+    if inline_functions_fast_functions:
+        dsk4 = inline_functions(dsk3, keys, dependencies=dependencies,
+                                fast_functions=inline_functions_fast_functions)
+    else:
+        dsk4 = dsk3
+    dsk5 = optimize_slices(dsk4)
+
+    return dsk5
+
+
+def hold_keys(dsk, dependencies):
+    """ Find keys to avoid fusion
+
+    We don't want to fuse data present in the graph because it is easier to
+    serialize as a raw value.
+
+    We don't want to fuse getitem/getarrays because we want to move around only
+    small pieces of data, rather than the underlying arrays.
+    """
+    dependents = reverse_dict(dependencies)
+    data = {k for k, v in dsk.items() if type(v) not in (tuple, str)}
+    getters = (getitem, getarray, getarray_inline)
+
+    hold_keys = list(data)
+    for dat in data:
+        deps = dependents[dat]
+        for dep in deps:
+            task = dsk[dep]
+            try:
+                if task[0] in getters:
+                    while len(dependents[dep]) == 1:
+                        new_dep = next(iter(dependents[dep]))
+                        new_task = dsk[new_dep]
+                        if new_task[0] in (getitem, getarray):
+                            dep = new_dep
+                            task = new_task
+                        else:
+                            break
+                    hold_keys.append(dep)
+            except (IndexError, TypeError):
+                pass
+    return hold_keys
 
 
 def optimize_slices(dsk):
@@ -46,7 +83,7 @@ def optimize_slices(dsk):
         fuse_slice_dict
     """
     fancy_ind_types = (list, np.ndarray)
-    getters = (getarray_nofancy, getarray, getitem)
+    getters = (getarray_nofancy, getarray, getitem, getarray_inline)
     dsk = dsk.copy()
     for k, v in dsk.items():
         if type(v) is tuple and v[0] in getters and len(v) == 3:
@@ -74,6 +111,8 @@ def optimize_slices(dsk):
                     # strictness e.g. `(getarray, (getitem, ...))` never
                     # happens
                     getter = f2
+                    if getter is getarray_inline:
+                        getter = getarray
                 except NotImplementedError:
                     break
                 a, a_index = b, c_index
