@@ -1,4 +1,5 @@
 from __future__ import absolute_import, division, print_function
+import copy
 
 import pytest
 np = pytest.importorskip('numpy')
@@ -27,7 +28,7 @@ from dask.array.core import (getem, getarray, getarray_nofancy, top, dotmany,
                              concatenate, from_array, take, elemwise, isnull,
                              notnull, broadcast_shapes, partial_by_order,
                              tensordot, choose, where, coarsen, insert,
-                             broadcast_to, reshape, fromfunction,
+                             broadcast_to, fromfunction,
                              blockdims_from_blockshape, store, optimize,
                              from_func, normalize_chunks, broadcast_chunks,
                              atop, from_delayed, concatenate_axes,
@@ -711,50 +712,59 @@ def test_ravel():
     assert_eq(np.ravel(x), da.ravel(a))
 
 
-def test_reshape():
-    cases = [
-        ((10,), (10,), (3, 3, 4)),
-        ((10,), (10, 1, 1), 5),
-        ((10,), (1, 10,), 5),
-        ((24,), (2, 3, 4), 12),
-        ((1, 24,), (2, 3, 4), 12),
-        ((2, 3, 4), (24,), (1, 3, 4)),
-        ((2, 3, 4), (24,), 4),
-        ((2, 3, 4), (24, 1), 4),
-        ((2, 3, 4), (1, 24), 4),
-        ((4, 4, 1), (4, 4), 2),
-        ((4, 4), (4, 4, 1), 2),
-        ((1, 4, 4), (4, 4), 2),
-        ((1, 4, 4), (4, 4, 1), 2),
-        ((1, 4, 4), (1, 1, 4, 4), 2),
-        ((4, 4), (1, 4, 4, 1), 2),
-        ((4, 4), (1, 4, 4), 2),
-        ((2, 3), (2, 3), (1, 2)),
-        ((2, 3), (3, 2), 3),
-        ((4, 2, 3), (4, 6), 4),
-        ((3, 4, 5, 6), (3, 4, 5, 6), (2, 3, 4, 5)),
-        ((), (1,), 1),
-        ((1,), (), 1),
-        ((24,), (3, 8), 24),
-        ((24,), (4, 6), 6),
-        ((24,), (4, 3, 2), 6),
-        ((24,), (4, 6, 1), 6),
-        ((24,), (4, 6), (6, 12, 6)),
-    ]
-    for original_shape, new_shape, chunks in cases:
-        x = np.random.randint(10, size=original_shape)
-        a = from_array(x, chunks=chunks)
-        assert_eq(x.reshape(new_shape), a.reshape(new_shape))
+@pytest.mark.parametrize('original_shape,new_shape,chunks', [
+    ((10,), (10,), (3, 3, 4)),
+    ((10,), (10, 1, 1), 5),
+    ((10,), (1, 10,), 5),
+    ((24,), (2, 3, 4), 12),
+    ((1, 24,), (2, 3, 4), 12),
+    ((2, 3, 4), (24,), (1, 3, 4)),
+    ((2, 3, 4), (24,), 4),
+    ((2, 3, 4), (24, 1), 4),
+    ((2, 3, 4), (1, 24), 4),
+    ((4, 4, 1), (4, 4), 2),
+    ((4, 4), (4, 4, 1), 2),
+    ((1, 4, 4), (4, 4), 2),
+    ((1, 4, 4), (4, 4, 1), 2),
+    ((1, 4, 4), (1, 1, 4, 4), 2),
+    ((4, 4), (1, 4, 4, 1), 2),
+    ((4, 4), (1, 4, 4), 2),
+    ((2, 3), (2, 3), (1, 2)),
+    ((2, 3), (3, 2), 3),
+    ((4, 2, 3), (4, 6), 4),
+    ((3, 4, 5, 6), (3, 4, 5, 6), (2, 3, 4, 5)),
+    ((), (1,), 1),
+    ((1,), (), 1),
+    ((24,), (3, 8), 24),
+    ((24,), (4, 6), 6),
+    ((24,), (4, 3, 2), 6),
+    ((24,), (4, 6, 1), 6),
+    ((24,), (4, 6), (6, 12, 6)),
+    ((64, 4), (8, 8, 4), (16, 2)),
+    ((4, 64), (4, 8, 4, 2), (2, 16)),
+    ((4, 8, 4, 2), (2, 1, 2, 32, 2), (2, 4, 2, 2)),
+    ((4, 1, 4), (4, 4), (2, 1, 2)),
+])
+def test_reshape(original_shape, new_shape, chunks):
+    x = np.random.randint(10, size=original_shape)
+    a = from_array(x, chunks=chunks)
+    assert_eq(x.reshape(new_shape), a.reshape(new_shape))
 
+
+def test_reshape_exceptions():
+    x = np.random.randint(10, size=(5,))
+    a = from_array(x, chunks=(2,))
     with pytest.raises(ValueError):
-        reshape(a, (100,))
-    assert_eq(x.reshape(*new_shape), a.reshape(*new_shape))
-    assert_eq(np.reshape(x, new_shape), reshape(a, new_shape))
+        da.reshape(a, (100,))
+
+
+def test_reshape_splat():
+    x = da.ones((5, 5), chunks=(2, 2))
+    assert_eq(x.reshape((25,)), x.reshape(25))
 
 
 def test_reshape_fails_for_dask_only():
     cases = [
-        ((10,), (2, 5), 3),
         ((3, 4), (4, 3), 2),
     ]
     for original_shape, new_shape, chunks in cases:
@@ -762,7 +772,7 @@ def test_reshape_fails_for_dask_only():
         a = from_array(x, chunks=chunks)
         assert x.reshape(new_shape).shape == new_shape
         with pytest.raises(ValueError):
-            reshape(a, new_shape)
+            da.reshape(a, new_shape)
 
 
 def test_reshape_unknown_dimensions():
@@ -772,7 +782,7 @@ def test_reshape_unknown_dimensions():
             a = from_array(x, 24)
             assert_eq(x.reshape(new_shape), a.reshape(new_shape))
 
-    pytest.raises(ValueError, lambda: reshape(a, (-1, -1)))
+    pytest.raises(ValueError, lambda: da.reshape(a, (-1, -1)))
 
 
 def test_full():
@@ -1470,6 +1480,24 @@ def test_from_array_slicing_results_in_ndarray():
     assert type(s3.compute()) == np.ndarray
 
 
+def test_asarray():
+    assert_eq(da.asarray([1, 2, 3]), np.asarray([1, 2, 3]))
+
+    x = da.asarray([1, 2, 3])
+    assert da.asarray(x) is x
+
+
+def test_asarray_h5py():
+    h5py = pytest.importorskip('h5py')
+
+    with tmpfile('.hdf5') as fn:
+        with h5py.File(fn) as f:
+            d = f.create_dataset('/x', shape=(2, 2), dtype=float)
+            x = da.asarray(d)
+            assert d in x.dask.values()
+            assert not any(isinstance(v, np.ndarray) for v in x.dask.values())
+
+
 def test_from_func():
     x = np.arange(10)
     f = lambda n: n * x
@@ -2055,6 +2083,11 @@ def test_to_delayed():
     [[a, b], [c, d]] = y.to_delayed()
     assert_eq(a.compute(), y[:2, :2])
 
+    s = 2
+    x = da.from_array(np.array(s), chunks=0)
+    a = x.to_delayed()[tuple()]
+    assert a.compute() == s
+
 
 def test_cumulative():
     x = da.arange(20, chunks=5)
@@ -2272,6 +2305,8 @@ def test_A_property():
 def test_copy_mutate():
     x = da.arange(5, chunks=(2,))
     y = x.copy()
+    memo = {}
+    y2 = copy.deepcopy(x, memo=memo)
     x[x % 2 == 0] = -1
 
     xx = np.arange(5)
@@ -2279,6 +2314,8 @@ def test_copy_mutate():
     assert_eq(x, xx)
 
     assert_eq(y, np.arange(5))
+    assert_eq(y2, np.arange(5))
+    assert memo[id(x)] is y2
 
 
 def test_npartitions():
@@ -2672,6 +2709,13 @@ def test_setitem_mixed_d():
     assert_eq(x, dx)
 
 
+def test_setitem_errs():
+    x = da.ones((4, 4), chunks=(2, 2))
+
+    with pytest.raises(ValueError):
+        x[x > 1] = x
+
+
 def test_zero_slice_dtypes():
     x = da.arange(5, chunks=1)
     y = x[[]]
@@ -2733,3 +2777,42 @@ def test_random_from_array():
 
     y2 = da.from_array(x, chunks=x.shape[0] / 10, name=False)
     assert y.name != y2.name
+
+
+def test_concatenate_errs():
+    with pytest.raises(ValueError) as e:
+        da.concatenate([da.zeros((2, 1), chunks=(2, 1)),
+                        da.zeros((2, 3), chunks=(2, 3))])
+
+    assert 'shape' in str(e).lower()
+    assert '(2, 1)' in str(e)
+
+    with pytest.raises(ValueError):
+        da.concatenate([da.zeros((1, 2), chunks=(1, 2)),
+                        da.zeros((3, 2), chunks=(3, 2))], axis=1)
+
+
+def test_stack_errs():
+    with pytest.raises(ValueError) as e:
+        da.stack([da.zeros((2), chunks=(2)),
+                  da.zeros((3), chunks=(3))])
+    assert 'shape' in str(e).lower()
+    assert '(2,)' in str(e)
+
+
+def test_transpose_negative_axes():
+    x = np.ones((2, 3, 4, 5))
+    y = da.ones((2, 3, 4, 5), chunks=3)
+
+    assert_eq(x.transpose([-1, -2, 0, 1]),
+              y.transpose([-1, -2, 0, 1]))
+
+
+def test_atop_with_numpy_arrays():
+    x = np.ones(10)
+    y = da.ones(10, chunks=(5,))
+
+    assert_eq(x + y, x + x)
+
+    s = da.sum(x)
+    assert any(x is v for v in s.dask.values())
