@@ -60,20 +60,20 @@ def test_arange():
     assert (sorted(da.arange(77, chunks=13, dtype=float).dask) ==
             sorted(da.arange(77, chunks=13, dtype=float).dask))
 
+    # 0 size output
+    darr = da.arange(0, 1, -0.5, chunks=20)
+    nparr = np.arange(0, 1, -0.5)
+    assert_eq(darr, nparr)
+
+    darr = da.arange(0, -1, 0.5, chunks=20)
+    nparr = np.arange(0, -1, 0.5)
+    assert_eq(darr, nparr)
+
 
 def test_arange_has_dtype():
     assert da.arange(5, chunks=2).dtype == np.arange(5).dtype
 
 
-def test_arange_working_float_step():
-    """Sometimes floating point step arguments work, but this could be platform
-    dependent.
-    """
-    darr = da.arange(3.3, -9.1, -.25, chunks=3)
-    nparr = np.arange(3.3, -9.1, -.25)
-    assert_eq(darr, nparr)
-
-
 @pytest.mark.xfail(reason="Casting floats to ints is not supported since edge"
                           "behavior is not specified or guaranteed by NumPy.")
 def test_arange_cast_float_int_step():
@@ -82,8 +82,6 @@ def test_arange_cast_float_int_step():
     assert_eq(darr, nparr)
 
 
-@pytest.mark.xfail(reason="arange with a floating point step value can fail"
-                          "due to numerical instability.")
 def test_arange_float_step():
     darr = da.arange(2., 13., .3, chunks=4)
     nparr = np.arange(2., 13., .3)
@@ -92,3 +90,11 @@ def test_arange_float_step():
     darr = da.arange(7.7, 1.5, -.8, chunks=3)
     nparr = np.arange(7.7, 1.5, -.8)
     assert_eq(darr, nparr)
+
+    darr = da.arange(0, 1, 0.01, chunks=20)
+    nparr = np.arange(0, 1, 0.01)
+    assert_eq(darr, nparr)
+
+    darr = da.arange(0, 1, 0.03, chunks=20)
+    nparr = np.arange(0, 1, 0.03)
+    assert_eq(darr, nparr)
