@@ -1,3 +1,5 @@
+import sys
+
 import pytest
 pytest.importorskip('sklearn')
 
@@ -28,6 +30,8 @@ Y = da.from_array(y, chunks=(3,))
 Z = da.from_array(z, chunks=(2, 2))
 
 
+@pytest.mark.skipif(sys.version_info >= (3, 6),
+                    reason="Hangs")
 def test_fit():
     sgd = SGDClassifier()
 
