@@ -4,7 +4,11 @@ from functools import partial
 from itertools import product
 
 import numpy as np
-from toolz import curry
+
+try:
+    from cytoolz import curry
+except ImportError:
+    from toolz import curry
 
 from ..base import tokenize
 from .core import Array, normalize_chunks
@@ -53,6 +57,7 @@ def wrap_func_shape_as_first_arg(func, *args, **kwargs):
     dsk = dict(zip(keys, vals))
     return Array(dsk, name, chunks, dtype=dtype)
 
+
 @curry
 def wrap(wrap_func, func, **kwargs):
     f = partial(wrap_func, func, **kwargs)
