@@ -109,14 +109,14 @@ def optimize(dsk, keys, fuse_keys=None, rename_fused_keys=True, **kwargs):
     """ Optimize a dask from a dask.bag """
     dsk2, dependencies = cull(dsk, keys)
     dsk3, dependencies = fuse(dsk2, keys + (fuse_keys or []), dependencies,
-                              rename_fused_keys=rename_fused_keys)
+                              rename_keys=rename_fused_keys)
     dsk4 = inline_singleton_lists(dsk3, dependencies)
     dsk5 = lazify(dsk4)
     return dsk5
 
 
 def to_textfiles(b, path, name_function=None, compression='infer',
-                 encoding=system_encoding, compute=True):
+                 encoding=system_encoding, compute=True, get=None):
     """ Write bag to disk, one filename per partition, one line per element
 
     **Paths**: This will create one file for each partition in your bag. You
@@ -174,7 +174,8 @@ def to_textfiles(b, path, name_function=None, compression='infer',
                       encoding=encoding)
     if compute:
         from dask import delayed
-        delayed(out).compute()
+        get = get or _globals.get('get', None) or Bag._default_get
+        delayed(out).compute(get=get)
     else:
         return out
 
@@ -589,8 +590,9 @@ class Bag(Base):
 
     @wraps(to_textfiles)
     def to_textfiles(self, path, name_function=None, compression='infer',
-                     encoding=system_encoding, compute=True):
-        return to_textfiles(self, path, name_function, compression, encoding, compute)
+                     encoding=system_encoding, compute=True, get=None):
+        return to_textfiles(self, path, name_function, compression, encoding,
+                            compute, get=get)
 
     def fold(self, binop, combine=None, initial=no_default, split_every=None):
         """ Parallelizable reduction
@@ -1300,53 +1302,6 @@ def from_sequence(seq, partition_size=None, npartitions=None):
     return Bag(d, name, len(d))
 
 
-def from_castra(x, columns=None, index=False):
-    """Load a dask Bag from a Castra.
-
-    Parameters
-    ----------
-    x : filename or Castra
-    columns: list or string, optional
-        The columns to load. Default is all columns.
-    index: bool, optional
-        If True, the index is included as the first element in each tuple.
-        Default is False.
-    """
-    from castra import Castra
-    if not isinstance(x, Castra):
-        x = Castra(x, readonly=True)
-    elif not x._readonly:
-        x = Castra(x.path, readonly=True)
-    if columns is None:
-        columns = x.columns
-
-    name = 'from-castra-' + tokenize(os.path.getmtime(x.path), x.path,
-                                     columns, index)
-    dsk = dict(((name, i), (load_castra_partition, x, part, columns, index))
-               for i, part in enumerate(x.partitions))
-    return Bag(dsk, name, len(x.partitions))
-
-
-def load_castra_partition(castra, part, columns, index):
-    import blosc
-    # Due to serialization issues, blosc needs to be manually initialized in
-    # each process.
-    blosc.init()
-
-    df = castra.load_partition(part, columns)
-    if isinstance(columns, list):
-        items = df.itertuples(index)
-    else:
-        items = df.iteritems() if index else iter(df)
-
-    items = list(items)
-    if items and isinstance(items[0], tuple) and type(items[0]) is not tuple:
-        names = items[0]._fields
-        items = [dict(zip(names, item)) for item in items]
-
-    return items
-
-
 def from_url(urls):
     """Create a dask.bag from a url
 
