@@ -11,10 +11,11 @@ import uuid
 from toolz import merge, groupby, curry, identity
 from toolz.functoolz import Compose
 
+from . import sharedict
 from .compatibility import bind_method, unicode, PY3
 from .context import _globals
 from .core import flatten
-from .utils import Dispatch
+from .utils import Dispatch, ensure_dict
 from .sharedict import ShareDict
 
 __all__ = ("Base", "compute", "normalize_token", "tokenize", "visualize")
@@ -97,7 +98,7 @@ class Base(object):
     @classmethod
     def _get(cls, dsk, keys, get=None, **kwargs):
         get = get or _globals['get'] or cls._default_get
-        dsk2 = cls._optimize(dict(dsk), keys, **kwargs)
+        dsk2 = cls._optimize(ensure_dict(dsk), keys, **kwargs)
         return get(dsk2, keys, **kwargs)
 
     @classmethod
@@ -251,7 +252,7 @@ def visualize(*args, **kwargs):
     optimize_graph = kwargs.pop('optimize_graph', False)
     from dask.dot import dot_graph
     if optimize_graph:
-        dsks.extend([arg._optimize(dict(arg.dask), arg._keys())
+        dsks.extend([arg._optimize(ensure_dict(arg.dask), arg._keys())
                      for arg in args])
     else:
         dsks.extend([arg.dask for arg in args])
@@ -260,7 +261,24 @@ def visualize(*args, **kwargs):
     return dot_graph(dsk, filename=filename, **kwargs)
 
 
+function_cache = {}
+
+
 def normalize_function(func):
+    try:
+        return function_cache[func]
+    except KeyError:
+        result = _normalize_function(func)
+        if len(function_cache) >= 500:  # clear half of cache if full
+            for k in list(function_cache)[::2]:
+                del function_cache[k]
+        function_cache[func] = result
+        return result
+    except TypeError:  # not hashable
+        return _normalize_function(func)
+
+
+def _normalize_function(func):
     if isinstance(func, curry):
         func = func._partial
     if isinstance(func, Compose):
@@ -408,12 +426,12 @@ def collections_to_dsk(collections, optimize_graph=True, **kwargs):
         groups = {opt: _extract_graph_and_keys(val)
                   for opt, val in groups.items()}
         for opt in optimizations:
-            groups = {k: [opt(dict(dsk), keys), keys]
+            groups = {k: [opt(ensure_dict(dsk), keys), keys]
                       for k, (dsk, keys) in groups.items()}
         dsk = merge([opt(dsk, keys, **kwargs)
                      for opt, (dsk, keys) in groups.items()])
     else:
-        dsk = merge(dict(c.dask) for c in collections)
+        dsk = ensure_dict(sharedict.merge(*[c.dask for c in collections]))
 
     return dsk
 
