@@ -1,7 +1,7 @@
 from __future__ import print_function, division, absolute_import
 
 from .io import (from_array, from_bcolz, from_array, from_bcolz,
-                 from_pandas, from_dask_array, from_castra, to_castra,
+                 from_pandas, from_dask_array,
                  from_delayed, dataframe_from_ctable, to_bag, to_records)
 from .csv import read_csv, to_csv, read_table
 from .hdf import read_hdf, to_hdf
