@@ -1,3 +1,6 @@
+from __future__ import absolute_import, division, print_function
+
+import numpy as np
 import pandas as pd
 from toolz import first, partial
 
@@ -118,6 +121,7 @@ def read_parquet(path, columns=None, filters=None, categories=None, index=None,
     meta = pd.DataFrame({c: pd.Series([], dtype=d)
                         for (c, d) in dtypes.items()},
                         columns=[c for c in pf.columns if c in dtypes])
+    meta = meta[list(all_columns)]
 
     for cat in categories:
         meta[cat] = pd.Series(pd.Categorical([],
@@ -140,6 +144,9 @@ def read_parquet(path, columns=None, filters=None, categories=None, index=None,
     else:
         divisions = (None,) * (len(rgs) + 1)
 
+    if isinstance(divisions[0], np.datetime64):
+        divisions = [pd.Timestamp(d) for d in divisions]
+
     return out_type(dsk, name, meta, divisions)
 
 
@@ -250,10 +257,10 @@ def to_parquet(path, df, compression=None, write_index=None, has_nulls=None,
             raise ValueError('Appended columns not the same.\n'
                              'New: {} | Previous: {}'
                              .format(pf.columns, list(df.columns)))
-        elif set(pf.dtypes.items()) != set(df.dtypes.items()):
+        elif set(pf.dtypes.items()) != set(df.dtypes.iteritems()):
             raise ValueError('Appended dtypes differ.\n{}'
                              .format(set(pf.dtypes.items()) ^
-                                     set(df.dtypes.items())))
+                                     set(df.dtypes.iteritems())))
         # elif fmd.schema != pf.fmd.schema:
         #    raise ValueError('Appended schema differs.')
         else:
@@ -288,10 +295,13 @@ def to_parquet(path, df, compression=None, write_index=None, has_nulls=None,
     out = delayed(writes).compute()
 
     for fn, rg in zip(filenames, out):
-        for chunk in rg.columns:
-            chunk.file_path = fn
-        fmd.row_groups.append(rg)
+        if rg is not None:
+            for chunk in rg.columns:
+                chunk.file_path = fn
+            fmd.row_groups.append(rg)
 
+    if len(fmd.row_groups) == 0:
+        raise ValueError("All partitions were empty")
     fastparquet.writer.write_common_metadata(metadata_fn, fmd, open_with=myopen,
                                              no_row_groups=False)
 
