@@ -1,6 +1,10 @@
+from __future__ import (absolute_import, division, print_function,
+                        unicode_literals)
+
 import os
 import numpy as np
 import pandas as pd
+import pandas.util.testing as tm
 import pytest
 
 import dask
@@ -19,7 +23,7 @@ def test_local():
         data = pd.DataFrame({'i32': np.arange(1000, dtype=np.int32),
                              'i64': np.arange(1000, dtype=np.int64),
                              'f': np.arange(1000, dtype=np.float64),
-                             'bhello': np.random.choice(['hello', 'you', 'people'], size=1000).astype("O")})
+                             'bhello': np.random.choice(['hello', 'yo', 'people'], size=1000).astype("O")})
         df = dd.from_pandas(data, chunksize=500)
 
         df.to_parquet(tmp, write_index=False, object_encoding='utf8')
@@ -144,7 +148,7 @@ def test_append():
         df = pd.DataFrame({'i32': np.arange(1000, dtype=np.int32),
                            'i64': np.arange(1000, dtype=np.int64),
                            'f': np.arange(1000, dtype=np.float64),
-                           'bhello': np.random.choice(['hello', 'you', 'people'],
+                           'bhello': np.random.choice(['hello', 'yo', 'people'],
                                                       size=1000).astype("O")})
         df.index.name = 'index'
 
@@ -164,7 +168,7 @@ def test_append_wo_index():
         df = pd.DataFrame({'i32': np.arange(1000, dtype=np.int32),
                            'i64': np.arange(1000, dtype=np.int64),
                            'f': np.arange(1000, dtype=np.float64),
-                           'bhello': np.random.choice(['hello', 'you', 'people'],
+                           'bhello': np.random.choice(['hello', 'yo', 'people'],
                                                       size=1000).astype("O")})
         half = len(df) // 2
         ddf1 = dd.from_pandas(df.iloc[:half], chunksize=100)
@@ -190,7 +194,7 @@ def test_append_overlapping_divisions():
                            'i64': np.arange(1000, dtype=np.int64),
                            'f': np.arange(1000, dtype=np.float64),
                            'bhello': np.random.choice(
-                               ['hello', 'you', 'people'],
+                               ['hello', 'yo', 'people'],
                                size=1000).astype("O")})
         half = len(df) // 2
         ddf1 = dd.from_pandas(df.iloc[:half], chunksize=100)
@@ -245,13 +249,28 @@ def test_ordering():
         assert_eq(ddf, ddf2)
 
 
+def test_read_parquet_custom_columns():
+    with tmpdir() as tmp:
+        tmp = str(tmp)
+        data = pd.DataFrame({'i32': np.arange(1000, dtype=np.int32),
+                             'f': np.arange(1000, dtype=np.float64)})
+        df = dd.from_pandas(data, chunksize=50)
+        df.to_parquet(tmp)
+
+        df2 = read_parquet(tmp, columns=['i32', 'f'])
+        assert_eq(df2, df2, check_index=False)
+
+        df3 = read_parquet(tmp, columns=['f', 'i32'])
+        assert_eq(df3, df3, check_index=False)
+
+
 @pytest.mark.parametrize('df,write_kwargs,read_kwargs', [
     (pd.DataFrame({'x': [3, 2, 1]}), {}, {}),
     (pd.DataFrame({'x': ['c', 'a', 'b']}), {'object_encoding': 'utf8'}, {}),
     (pd.DataFrame({'x': ['cc', 'a', 'bbb']}), {'object_encoding': 'utf8'}, {}),
     (pd.DataFrame({'x': [b'a', b'b', b'c']}), {'object_encoding': 'bytes'}, {}),
-    (pd.DataFrame({'x': pd.Categorical(['a', 'b', 'a'])}), {'object_encoding': 'utf8'},
-                                                           {'categories': ['x']}),
+    (pd.DataFrame({'x': pd.Categorical(['a', 'b', 'a'])}),
+     {'object_encoding': 'utf8'}, {'categories': ['x']}),
     (pd.DataFrame({'x': pd.Categorical([1, 2, 1])}), {}, {'categories': ['x']}),
     (pd.DataFrame({'x': list(map(pd.Timestamp, [3000, 2000, 1000]))}), {}, {}),
     (pd.DataFrame({'x': [3000, 2000, 1000]}).astype('M8[ns]'), {}, {}),
@@ -305,3 +324,30 @@ def test_categories(fn):
     with pytest.raises(ValueError):
         # attempt to load as category unknown column
         ddf2 = dd.read_parquet(fn, categories=['foo'])
+
+
+def test_empty_partition(fn):
+    df = pd.DataFrame({"a": range(10), "b": range(10)})
+    ddf = dd.from_pandas(df, npartitions=5)
+
+    # fails as there are empty partitions
+    ddf2 = ddf[ddf.a <= 5]
+    ddf2.to_parquet(fn)
+
+    ddf3 = dd.read_parquet(fn)
+    assert_eq(ddf2.compute(), ddf3.compute(), check_names=False,
+              check_index=False)
+
+    ddf2 = ddf[ddf.a <= -5]
+    with pytest.raises(ValueError):
+        ddf2.to_parquet(fn)
+
+
+def test_timestamp_index():
+    with tmpfile() as fn:
+        df = tm.makeTimeDataFrame()
+        df.index.name = 'foo'
+        ddf = dd.from_pandas(df, npartitions=5)
+        ddf.to_parquet(fn)
+        ddf2 = dd.read_parquet(fn)
+        assert_eq(ddf, ddf2)
