@@ -9,11 +9,14 @@ import pandas as pd
 from toolz import merge
 
 from .methods import drop_columns
-from .core import DataFrame, Series, _Frame, _concat
+from .core import DataFrame, Series, _Frame, _concat, map_partitions
 from .hashing import hash_pandas_object
 
-from ..base import tokenize
+from .. import base
+from ..base import tokenize, compute
 from ..context import _globals
+from ..delayed import delayed
+from ..sizeof import sizeof
 from ..utils import digit, insert, M
 
 
@@ -28,16 +31,49 @@ def set_index(df, index, npartitions=None, shuffle=None, compute=False,
             "You tried to index with this index: %s\n"
             "Indexes must be single columns only." % str(index))
 
-    npartitions = npartitions or df.npartitions
+    if npartitions == 'auto':
+        repartition = True
+        npartitions = max(100, df.npartitions)
+    else:
+        if npartitions is None:
+            npartitions = df.npartitions
+        repartition = False
+
     if not isinstance(index, Series):
         index2 = df[index]
     else:
         index2 = index
 
     if divisions is None:
-        divisions = (index2
-                     ._repartition_quantiles(npartitions, upsample=upsample)
-                     .compute()).tolist()
+        divisions = index2._repartition_quantiles(npartitions, upsample=upsample)
+        if repartition:
+            parts = df.to_delayed()
+            sizes = [delayed(sizeof)(part) for part in parts]
+        else:
+            sizes = []
+        iparts = index2.to_delayed()
+        mins = [ipart.min() for ipart in iparts]
+        maxes = [ipart.max() for ipart in iparts]
+        divisions, sizes, mins, maxes = base.compute(divisions, sizes, mins, maxes)
+        divisions = divisions.tolist()
+
+        if repartition:
+            total = sum(sizes)
+            npartitions = max(math.ceil(total / 128e6), 1)
+            npartitions = min(npartitions, df.npartitions)
+            n = len(divisions)
+            try:
+                divisions = np.interp(x=np.linspace(0, n - 1, npartitions + 1),
+                                      xp=np.arange(0, len(divisions)),
+                                      fp=divisions).tolist()
+            except (TypeError, ValueError):  # str type
+                indexes = np.linspace(0, n - 1, npartitions + 1).astype(int)
+                divisions = [divisions[i] for i in indexes]
+
+        if (mins == sorted(mins) and maxes == sorted(maxes) and
+                all(mx < mn for mx, mn in zip(maxes[:-1], mins[1:]))):
+            divisions = mins + [maxes[-1]]
+            return set_sorted_index(df, index, drop=drop, divisions=divisions)
 
     return set_partition(df, index, divisions, shuffle=shuffle, drop=drop,
                          compute=compute, **kwargs)
@@ -154,8 +190,6 @@ def rearrange_by_column(df, col, npartitions=None, max_branch=None,
     if shuffle == 'disk':
         return rearrange_by_column_disk(df, col, npartitions, compute=compute)
     elif shuffle == 'tasks':
-        if npartitions is not None and npartitions < df.npartitions:
-            raise ValueError("Must create as many or more partitions in shuffle")
         return rearrange_by_column_tasks(df, col, max_branch, npartitions)
     else:
         raise NotImplementedError("Unknown shuffle method %s" % shuffle)
@@ -337,8 +371,16 @@ def set_partitions_pre(s, divisions):
 
 
 def shuffle_group_2(df, col):
-    g = df.groupby(col)
-    return {i: g.get_group(i) for i in g.groups}, df.head(0)
+    if not len(df):
+        return {}, df
+    ind = df[col]._values.astype(np.int64)
+    n = ind.max() + 1
+    indexer, locations = pd.algos.groupsort_indexer(ind.view(np.int64), n)
+    df2 = df.take(indexer)
+    locations = locations.cumsum()
+    parts = [df2.iloc[a:b] for a, b in zip(locations[:-1], locations[1:])]
+    result2 = dict(zip(range(n), parts))
+    return result2, df.iloc[:0]
 
 
 def shuffle_group_get(g_head, i):
@@ -351,12 +393,27 @@ def shuffle_group_get(g_head, i):
 
 def shuffle_group(df, col, stage, k, npartitions):
     if col == '_partitions':
-        ind = df[col].values % npartitions
+        ind = df[col]
     else:
-        ind = partitioning_index(df[col], npartitions)
-    c = ind // k ** stage % k
-    g = df.groupby(c)
-    return {i: g.get_group(i) if i in g.groups else df.head(0) for i in range(k)}
+        ind = hash_pandas_object(df[col], index=False)
+
+    c = ind._values
+    typ = np.min_scalar_type(npartitions * 2)
+    c = c.astype(typ)
+
+    npartitions, k, stage = [np.array(x, dtype=np.min_scalar_type(x))[()]
+                             for x in [npartitions, k, stage]]
+
+    c = np.mod(c, npartitions, out=c)
+    c = np.floor_divide(c, k ** stage, out=c)
+    c = np.mod(c, k, out=c)
+
+    indexer, locations = pd.algos.groupsort_indexer(c.astype(np.int64), k)
+    df2 = df.take(indexer)
+    locations = locations.cumsum()
+    parts = [df2.iloc[a:b] for a, b in zip(locations[:-1], locations[1:])]
+
+    return dict(zip(range(k), parts))
 
 
 def shuffle_group_3(df, col, npartitions, p):
@@ -376,3 +433,33 @@ def set_index_post_series(df, index_name, drop, column_dtype):
     df2.index.name = index_name
     df2.columns = df2.columns.astype(column_dtype)
     return df2
+
+
+def set_sorted_index(df, index, drop=True, divisions=None, **kwargs):
+    if not isinstance(index, Series):
+        meta = df._meta.set_index(index, drop=drop)
+    else:
+        meta = df._meta.set_index(index._meta, drop=drop)
+
+    result = map_partitions(M.set_index, df, index, drop=drop, meta=meta)
+
+    if not divisions:
+        divisions = compute_divisions(result, **kwargs)
+
+    result.divisions = tuple(divisions)
+    return result
+
+
+def compute_divisions(df, **kwargs):
+    mins = df.index.map_partitions(M.min, meta=df.index)
+    maxes = df.index.map_partitions(M.max, meta=df.index)
+    mins, maxes = compute(mins, maxes, **kwargs)
+
+    if (sorted(mins) != list(mins) or
+            sorted(maxes) != list(maxes) or
+            any(a > b for a, b in zip(mins, maxes))):
+        raise ValueError("Partitions must be sorted ascending with the index",
+                         mins, maxes)
+
+    divisions = tuple(mins) + (list(maxes)[-1],)
+    return divisions
