@@ -194,12 +194,12 @@ def test_set_index():
 
 
 def test_set_index_interpolate():
-    df = pd.DataFrame({'x': [1, 1, 1, 3, 3], 'y': [1., 1, 1, 1, 2]})
+    df = pd.DataFrame({'x': [4, 1, 1, 3, 3], 'y': [1., 1, 1, 1, 2]})
     d = dd.from_pandas(df, 2)
 
     d1 = d.set_index('x', npartitions=3)
     assert d1.npartitions == 3
-    assert set(d1.divisions) == set([1, 2, 3])
+    assert set(d1.divisions) == set([1, 2, 3, 4])
 
     d2 = d.set_index('y', npartitions=3)
     assert d2.divisions[0] == 1.
@@ -224,14 +224,14 @@ def test_set_index_timezone():
     d1 = d.set_index('notz', npartitions=2)
     s1 = pd.DatetimeIndex(s_naive.values, dtype=s_naive.dtype)
     assert d1.divisions[0] == s_naive[0] == s1[0]
-    assert d1.divisions[2] == s_naive[2] == s1[2]
+    assert d1.divisions[-1] == s_naive[2] == s1[2]
 
     # We currently lose "freq".  Converting data with pandas-defined dtypes
     # to numpy or pure Python can be lossy like this.
     d2 = d.set_index('tz', npartitions=2)
-    s2 = pd.DatetimeIndex(s_aware.values, dtype=s_aware.dtype)
+    s2 = pd.DatetimeIndex(s_aware, dtype=s_aware.dtype)
     assert d2.divisions[0] == s2[0]
-    assert d2.divisions[2] == s2[2]
+    assert d2.divisions[-1] == s2[2]
     assert d2.divisions[0].tz == s2[0].tz
     assert d2.divisions[0].tz is not None
     s2badtype = pd.DatetimeIndex(s_aware.values, dtype=s_naive.dtype)
@@ -239,6 +239,19 @@ def test_set_index_timezone():
         d2.divisions[0] == s2badtype[0]
 
 
+@pytest.mark.parametrize(
+    'npartitions',
+    [1, pytest.mark.xfail(2, reason='pandas join removes freq')]
+)
+def test_timezone_freq(npartitions):
+    s_naive = pd.Series(pd.date_range('20130101', periods=10))
+    s_aware = pd.Series(pd.date_range('20130101', periods=10, tz='US/Eastern'))
+    pdf = pd.DataFrame({'tz': s_aware, 'notz': s_naive})
+    ddf = dd.from_pandas(pdf, npartitions=npartitions)
+
+    assert pdf.tz[0].freq == ddf.compute().tz[0].freq == ddf.tz.compute()[0].freq
+
+
 @pytest.mark.parametrize('drop', [True, False])
 def test_set_index_drop(drop):
 
@@ -1275,6 +1288,32 @@ def test_repartition_npartitions():
             a.repartition(npartitions=5)
 
 
+@pytest.mark.slow
+@pytest.mark.parametrize('npartitions', [1, 20, 243])
+@pytest.mark.parametrize('freq', ['1D', '7D', '28h'])
+@pytest.mark.parametrize('end', ['2000-04-15', '2000-04-15 12:37:01'])
+@pytest.mark.parametrize('start', ['2000-01-01', '2000-01-01 12:30:00'])
+def test_repartition_freq(npartitions, freq, start, end):
+    start = pd.Timestamp(start)
+    end = pd.Timestamp(end)
+    ind = pd.DatetimeIndex(start=start, end=end, freq='60s')
+    df = pd.DataFrame({'x': np.arange(len(ind))}, index=ind)
+    ddf = dd.from_pandas(df, npartitions=npartitions, name='x')
+
+    ddf2 = ddf.repartition(freq=freq)
+    assert_eq(ddf2, df)
+
+
+def test_repartition_freq_errors():
+    df = pd.DataFrame({'x': [1, 2, 3]})
+    ddf = dd.from_pandas(df, npartitions=1)
+    with pytest.raises(TypeError) as info:
+        ddf.repartition(freq='1s')
+
+    assert 'only' in str(info.value)
+    assert 'timeseries' in str(info.value)
+
+
 def test_embarrassingly_parallel_operations():
     df = pd.DataFrame({'x': [1, 2, 3, 4, None, 6], 'y': list('abdabd')},
                       index=[10, 20, 30, 40, 50, 60])
@@ -2150,7 +2189,7 @@ def test_set_index_sorted_true():
 
 
 def test_compute_divisions():
-    from dask.dataframe.core import compute_divisions
+    from dask.dataframe.shuffle import compute_divisions
     df = pd.DataFrame({'x': [1, 2, 3, 4],
                        'y': [10, 20, 30, 40],
                        'z': [4, 3, 2, 1]},
@@ -2162,7 +2201,7 @@ def test_compute_divisions():
     b = copy(a)
     b.divisions = divisions
 
-    assert_eq(a, b)
+    assert_eq(a, b, check_divisions=False)
     assert b.known_divisions
 
 
@@ -2618,3 +2657,39 @@ def test_del():
 
     del df['x']
     assert_eq(a, df)
+
+
+@pytest.mark.parametrize('index', [True, False])
+@pytest.mark.parametrize('deep', [True, False])
+def test_memory_usage(index, deep):
+    df = pd.DataFrame({'x': [1, 2, 3],
+                       'y': [1.0, 2.0, 3.0],
+                       'z': ['a', 'b', 'c']})
+    ddf = dd.from_pandas(df, npartitions=2)
+
+    assert_eq(df.memory_usage(index=index, deep=deep),
+              ddf.memory_usage(index=index, deep=deep))
+    assert (df.x.memory_usage(index=index, deep=deep) ==
+            ddf.x.memory_usage(index=index, deep=deep).compute())
+
+
+@pytest.mark.parametrize('reduction', ['sum', 'mean', 'std', 'var', 'count',
+                                       'min', 'max', 'idxmin', 'idxmax',
+                                       'prod', 'all', 'sem'])
+def test_dataframe_reductions_arithmetic(reduction):
+    df = pd.DataFrame({'x': [1, 2, 3, 4, 5],
+                       'y': [1.1, 2.2, 3.3, 4.4, 5.5]})
+    ddf = dd.from_pandas(df, npartitions=3)
+
+    assert_eq(ddf - (getattr(ddf, reduction)() + 1),
+              df - (getattr(df, reduction)() + 1))
+
+
+def test_datetime_loc_open_slicing():
+    dtRange = pd.date_range('01.01.2015','05.05.2015')
+    df = pd.DataFrame(np.random.random((len(dtRange), 2)), index=dtRange)
+    ddf = dd.from_pandas(df, npartitions=5)
+    assert_eq(df.loc[:'02.02.2015'], ddf.loc[:'02.02.2015'])
+    assert_eq(df.loc['02.02.2015':], ddf.loc['02.02.2015':])
+    assert_eq(df[0].loc[:'02.02.2015'], ddf[0].loc[:'02.02.2015'])
+    assert_eq(df[0].loc['02.02.2015':], ddf[0].loc['02.02.2015':])
