@@ -31,6 +31,14 @@ def test_to_task_dask():
     assert task == x
     assert dict(dask) == {}
 
+    # Issue https://github.com/dask/dask/issues/2107
+    class MyClass(dict):
+        pass
+
+    task, dask = to_task_dask(MyClass())
+    assert type(task) is MyClass
+    assert dict(dask) == {}
+
 
 def test_delayed():
     add2 = delayed(add)
@@ -69,6 +77,7 @@ def test_methods():
 
 def test_attributes():
     a = delayed(2 + 1j)
+    assert a.real._key == a.real._key
     assert a.real.compute() == 2
     assert a.imag.compute() == 1
     assert (a.real + a.imag).compute() == 3
