@@ -17,7 +17,6 @@ from contextlib import contextmanager
 from importlib import import_module
 from threading import Lock
 import multiprocessing as mp
-from . import multiprocessing
 import uuid
 from weakref import WeakValueDictionary
 
@@ -75,6 +74,8 @@ def ndeepmap(n, func, seq):
         return [func(item) for item in seq]
     elif n > 1:
         return [ndeepmap(n - 1, func, item) for item in seq]
+    elif isinstance(seq, list):
+        return func(seq[0])
     else:
         return func(seq)
 
@@ -543,9 +544,11 @@ def takes_multiple_arguments(func):
 
 class Dispatch(object):
     """Simple single dispatch."""
-    def __init__(self):
+    def __init__(self, name=None):
         self._lookup = {}
         self._lazy = {}
+        if name:
+            self.__name__ = name
 
     def register(self, type, func=None):
         """Register dispatch of `func` on arguments of type `type`"""
@@ -1033,8 +1036,20 @@ def effective_get(get=None, collection=None):
 def get_scheduler_lock(get=None, collection=None):
     """Get an instance of the appropriate lock for a certain situation based on
        scheduler used."""
+    from . import multiprocessing
     actual_get = effective_get(get, collection)
 
     if actual_get == multiprocessing.get:
         return mp.Manager().Lock()
     return SerializableLock()
+
+
+def ensure_dict(d):
+    if type(d) is dict:
+        return d
+    elif hasattr(d, 'dicts'):
+        result = {}
+        for dd in d.dicts.values():
+            result.update(dd)
+        return result
+    return dict(d)
